#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# COPYRIGHT (c) 1996 European Southern Observatory
# LICENSE
#
# PROJECT:   VLT Data Flow System
# AUTHOR:    Jeremy Maxfield
# CI NUMBER: 
#
# DESCRIPTION: DFS configuration file for hosts and accounts
# REMARKS:     It must be edit by dfsinstall and table-dfs
#
# $Id: dataflowUser.sh,v 1.69 2010/05/27 13:49:59 cguirao Exp $
#
# Revision history:  see end of file
#
#******************************************************

# ROLEs -MACHINES association
##################
if [ -z "$PipelineWS" ]; then
  export PipelineWS=$HOSTNAME
fi
if [ -z "$OhsWS" ]; then
  export OhsWS=BLANK
fi
if [ -z "$OlasWS" ]; then
  export OlasWS=BLANK
fi
if [ -z "$DataTransferWS" ]; then
  export DataTransferWS=pastage_vip
fi
if [ -z "$QcWS" ]; then
  export QcWS=$HOSTNAME
fi
if [ -z "$UserWS" ]; then
  export UserWS=BLANK
fi
if [ -z "$InstrWS" ]; then
  export InstrWS=BLANK
fi
if [ -z "$AstoWS" ]; then
  export AstoWS=BLANK
fi
export SYBASE_SERVER=ESOECF_DIRECT
export CCS_ENVIRONMENT=BLANK
export DFS_NGAMS_SERVERS_ARCHIVE=ngau1.hq.eso.org:7777,ngau2.hq.eso.org:7777
export DFS_NGAMS_SERVERS_PREIMAGE=ngau1.hq.eso.org:7777,ngau2.hq.eso.org:7777
export DFS_OLAS_MGR=cguirao@eso.org
##################


#
# if DFS_HOST is defined, it behaves as such host
#
if [ -z "$DFS_HOST" ]; then
  DFS_HOST=`uname -n`
fi

#
# if DFS_USER is defined, it behaves as such account
# return if flowmgr
#
if [ -z "$DFS_USER" ]; then
  export DFS_USER=`whoami`
fi

#
# if DFS_RELEASE is undefined use 'dfs' by default.
#
if [ -z "$DFS_RELEASE" ]; then
  export DFS_RELEASE=dfs
fi

# Define VLT specific only if not already defined via pecs
if [ -z "$VLTSW_ROOTDIR" ]; then
  export CC=gcc
  export VLTSW_ROOTDIR=/vlt
  export VLTSW_RELEASE=VLT2010
  export JAVA_HOME=${VLTSW_ROOTDIR}/${VLTSW_RELEASE}/jdk1.6.0_18
  export MIDASHOME=${VLTSW_ROOTDIR}/${VLTSW_RELEASE}/midas
  export MIDVERS=09SEPpl1.2
  export TCLTK_ROOT=${VLTSW_ROOTDIR}/${VLTSW_RELEASE}/tcltk
  export CMM_HOST=te13.hq.eso.org
  export CMM_PORT=3000

  case ${DFS_USER} in
  visitor|service|instmgr) 
    export VLTSW_CCSTYPE=CCSLite
    export RTAPENV=$CCS_ENVIRONMENT
    ;;
  *)
    export VLTSW_CCSTYPE=NOCCS
    ;;
  esac
  # CG. VLTROOT needed by dataSubscriber
  export  VLTROOT=${VLTSW_ROOTDIR}/${VLTSW_RELEASE}/${VLTSW_CCSTYPE}

  export PATH=${VLTSW_ROOTDIR}/${VLTSW_RELEASE}/${VLTSW_CCSTYPE}/bin:${JAVA_HOME}/bin:${VLTSW_ROOTDIR}/${VLTSW_RELEASE}/tcltk/bin:${VLTSW_ROOTDIR}/${VLTSW_RELEASE}/gnu/bin:${MIDASHOME}/${MIDVERS}/system/unix:${PATH}
  export LD_LIBRARY_PATH=${VLTSW_ROOTDIR}/${VLTSW_RELEASE}/${VLTSW_CCSTYPE}/lib:${VLTSW_ROOTDIR}/${VLTSW_RELEASE}/gnu/lib:$LD_LIBRARY_PATH
fi



#
# Setup for all users
#
export DFS_ROOT=~flowmgr
export DFS_HOME=${DFS_ROOT}/${DFS_RELEASE}
export DFS_HELP=${DFS_HOME}/help
export HOST=${DFS_HOST}

#
# If DFS_PIPELINE_FULL defined this is a pipeline in Paranal/La Silla
# Otherwise is a DFO pipeline (only for dfscheck.sh purposes)
#
export DFS_PIPELINE_FULL=1

#
# If INTROOT is undefined use ${DFS_RELEASE}/INTROOT by default
# If INTROOT is defined, PECS will add it to PATH and MANTPATH
#
if [ -z "$INTROOT" ]; then
  export INTROOT=${DFS_ROOT}/${DFS_RELEASE}/INTROOT
  export PATH=${INTROOT}/bin:${PATH}
  export MANPATH=${INTROOT}/man:${MANPATH}
fi

if [ -z "$SYBASE" ]; then
  unset LANG
  export SYBASE=/opt/sybase
fi

if [ -z "$ACE" ]; then
  export ACE=/opt/ACE
fi

if [ -z "$QFITS" ]; then
  export QFITS=/opt/qfits
fi
export PATH=${QFITS}/bin:${PATH}

if [ -z "$LD_LIBRARY_PATH" ]; then
  export LD_LIBRARY_PATH=${DFS_HOME}/lib:${DFS_HOME}/cpl/lib
else
  export LD_LIBRARY_PATH=${DFS_HOME}/lib:${DFS_HOME}/cpl/lib:${LD_LIBRARY_PATH}
fi

#
# Make sure that DHS_HOST and DHS_CONFIG is not defined
#
unset DHS_HOST
unset DHS_CONFIG
   
export PATH=${DFS_HOME}/bin:${DFS_HOME}/gasgano/bin:${DFS_HOME}/dfslog/bin:${DFS_HOME}/BetJava/bin:${DFS_HOME}/cpl/bin:${DFS_HOME}/dfsexport/bin:${PATH}
export MANPATH=${DFS_HOME}/man:${DFS_HOME}/BetJava/man:${MANPATH}

if [ ${DFS_HOST} = $PipelineWS ]; then
  export PIPE_HOME=/home/quality/pipelines
  export CPLDIR=${DFS_HOME}/cpl
  export DFS_GASGANO_CONFIG_DIR=/home/quality/gasgano/config
  export DFS_RBS_DIR=/home/quality/RBS
  export GSLDIR=/opt/gsl
  export FFTWDIR=/vlt/VLT2010/gnu
  export WCSDIR=/opt/wcs
  export CFITSIODIR=/vlt/VLT2010/gnu
  export LAPACKDIR=/opt/clapack

  #
  # if DFS_ACCOUNT_ROLE is defined, dataflowUser.sh behaves as such account
  #
  if [ -n "$DFS_ACCOUNT_ROLE" ]; then
     export DFS_USER=$DFS_ACCOUNT_ROLE
  fi

  #
  # To have a chance to change the DFS data location
  #
  if [ -z "$DFS_DATA_ROOT" ]; then
      export DFS_DATA_ROOT=/data
  fi
 
  case ${DFS_USER} in
  quality) 
    export DFS_QC1_LOG_DIR=${DFS_DATA_ROOT}/msg
    export DFS_QC1_DIC_DIR=~/qc1/Dictionary
    export DFC_DB_ROOT=${DFS_DATA_ROOT}
    export DFS_DO_DB=$DFS_DATA_ROOT/calibDB/certif/ins
    export INS_ROOT=~quality/INS_ROOT
    ;;

  pipeline) 
    export DFS_DHS_THREADS=1
    export OLAS_ID=PRO
    export DFC_DB_ROOT=${DFS_DATA_ROOT}
    export DFS_DO_DB=$DFS_DATA_ROOT/calibDB/certif/ins
    export DFS_REDBLOCK=${DFS_DATA_ROOT}/redblock
    export DFS_PRODUCT=${DFS_DATA_ROOT}/lists/reduced_do
    export DFS_DATA_REDUCED=${DFS_DATA_ROOT}/reduced
    export DFS_LOG=${DFS_DATA_ROOT}/msg
    export INS_ROOT=~quality/INS_ROOT
    export DSQUERY=$SYBASE_SERVER
    export DHS_DATA=${DFS_DATA_ROOT}/raw
    export DFS_PIPE_ALLPRODUCTS=YES
    export DFS_DATA_RAW=${DFS_DATA_ROOT}/raw
    export DFS_QC_RAW=${DFS_DATA_ROOT}/lists/raw_qcm
    export DFS_DO_RAW=${DFS_DATA_ROOT}/lists/raw_do
    export DFS_DATA_RAW_DO=${DFS_DO_RAW}
    export DFS_DATA_RAW_QCM=${DFS_QC_RAW}
    export DFS_DATA_MSG=${DFS_DATA_ROOT}/msg
    export DFS_QC_LOG=${DFS_DATA_ROOT}/msg
    export DHS_HOST=$OlasWS
    export DHS_CONFIG=archeso@${OlasWS}:/data/msg
    export BAD_DIR=${DFS_DATA_ROOT}/bad
    export DHS_LOG=${DFS_LOG}
    export DFS_DATA_REDUCED_OLAS=${DFS_DATA_ROOT}/lists/reduced_olas
    export DFS_QC_TESTING=0
    export DFS_QC1_LOG_DIR=$DFS_LOG
    export DFS_QC1_DIC_DIR=~quality/qc1/Dictionary
    export DFS_DATA_BACKLOG=${DFS_DATA_ROOT}/backlog
    export DFS_RBS_TMP=${DFS_DATA_ROOT}/RBStmp
    export DFS_RBS_CONFIG=~quality/RBS
    if [ -d /opt/python ]; then
      export PATH=/opt/python/bin:$PATH
      if [ -z "$PYTHONPATH" ]; then
	export PYTHONPATH=${DFS_ROOT}/${DFS_RELEASE}/packages
      else
	export PYTHONPATH=${DFS_ROOT}/${DFS_RELEASE}/packages:$PYTHONPATH
      fi
    fi
    ;;
  esac
fi

if [ ${DFS_HOST} =  $OlasWS  ]; then 
  case ${DFS_USER} in
  archeso) 
    export DFS_DHS_THREADS=1
    #
    # If there is a /data_secondary directory (or a link to a directory)
    # sets the DHS variables to default values.
    # See man page for dhs (command: 'man dhs') for details
    #
    if [ -d /data_secondary ] ; then
      export DHS_SECONDARY_DATA=/data_secondary
      export DHS_CRITICAL_DISK_SPACE=500
      export DHS_OPERATIONAL_DISK_SPACE=12000
      export DHS_IDLE_TIME_START=15:00
      export DHS_IDLE_TIME_STOP=22:00
    fi
    export DHS_DATA=/data/raw
    export DHS_LOG=/data/msg
    export BAD_DIR=/data/bad
    export DHS_HOST=$OlasWS
    export DHS_CONFIG=archeso@${DHS_HOST}:/data/msg
    export INS_ROOT=~archeso/INS_ROOT
    export DSQUERY=$SYBASE_SERVER
    export DFS_DATA_RAW=/data/raw
    export DFS_DATA_MSG=/data/msg
    export DFS_DATA_NGAMS_ARCHIVE=/data/raw-ngams-archive
    export DFS_DATA_NGAMS_PREIMAGE=/data/raw-ngams-preimage
    export DFS_BACKLOG_NGAMS_ARCHIVE=/data/backlog-ngams-archive
    export DFS_BACKLOG_NGAMS_PREIMAGE=/data/backlog-ngams-preimage
    export DFS_TOO_RAW=/data/too-raw
    export DFS_TOO_MSG=/data/msg
    export DFS_TOO_BACKLOG=/data/too-backlog
    export DFS_TOO_LIST=/home/archeso/toolist.dat
    export DFS_TOO_STAGE=/data/too
    ;;
  esac
fi	

if [ ${DFS_HOST} =  $UserWS  ]; then  
  alias gasgano230='PATH=$DFS_HOME/gasgano230/bin:$PATH  gasgano'
  case ${DFS_USER} in
  astro) 
    if [ -z "$DFS_DATA_ROOT" ]; then
        export DFS_DATA_ROOT=/data
    fi
    export DHS_HOST=$OlasWS
    export DHS_CONFIG=archeso@${DHS_HOST}:/data/msg
    export DHS_DATA=${DFS_DATA_ROOT}/raw
    export DHS_LOG=${DFS_DATA_ROOT}/msg
    export BAD_DIR=${DFS_DATA_ROOT}/bad
    export DFS_DATA_RAW=${DFS_DATA_ROOT}/raw
    export DFS_DATA_REDUCED=${DFS_DATA_ROOT}/reduced
    export DFS_DATA_MSG=${DFS_DATA_ROOT}/msg
    export DFS_DATA_BACKLOG=${DFS_DATA_ROOT}/backlog
    export DFS_GUI_CONFIG=${INTROOT}/config
    export INS_ROOT=${DFS_ROOT}/${DFS_RELEASE}/data
    export DSQUERY=$SYBASE_SERVER
    export CPLDIR=${DFS_HOME}/cpl
    ;;
  esac
fi

if [ ${DFS_HOST} =  $AstoWS  ]; then 
  case ${DFS_USER} in
  archeso) 
    if [ -z "$DFS_DATA_ROOT" ]; then
        export DFS_DATA_ROOT=/data
    fi
    export OlasWS=BLANK
    export DHS_DATA=${DFS_DATA_ROOT}/raw
    export DHS_LOG=${DFS_DATA_ROOT}/msg
    export BAD_DIR=${DFS_DATA_ROOT}/bad
    export DHS_HOST=$OlasWS
    export DHS_CONFIG=archeso@${DHS_HOST}:/data/msg
    export ASTO_HOST=$AstoWS
    export ASTO_STAGE_ROOT=/data/media/stage
    export ASTO_CONFIG_DIR=~archeso/astoconf
    export ASTO_REQ_DIR=/data/media/romanic
    export DEFAULT_CONFIG_DIR=~archeso/astoconf
    export DFS_DATA_RAW=${DFS_DATA_ROOT}/raw
    export DFS_DATA_REDUCED=${DFS_DATA_ROOT}/reduced
    export DFS_DATA_MSG=${DFS_DATA_ROOT}/msg
    export DFS_BACKLOG=${DFS_DATA_ROOT}/backlog
    export DSQUERY=$SYBASE_SERVER
    export GEAR_WRITERS=1
    export INS_ROOT=${DFS_ROOT}/${DFS_RELEASE}/data
    export PATH=${SYBASE}/bin:/opt/cdrecord/bin:${PATH}
    export PATH=${DFS_ROOT}/${DFS_RELEASE}/asto/bin:${PATH}
    export PATH=${DFS_ROOT}/${DFS_RELEASE}/asto/scripts:${PATH}
    export DFS_DATA_BACKLOG=${DFS_DATA_ROOT}/backlog
    ;;
  esac
fi

if [ ${DFS_HOST} =  $DataTransferWS  ]; then 
  case ${DFS_USER} in
  archeso) 
    if [ -d /opt/cfitstools ]; then
      export PATH=/opt/cfitstools/bin:$PATH
    fi
    if [ -d /opt/bbcp ]; then
      export PATH=/opt/bbcp/bin:$PATH
    fi
    if [ -z "$DFS_DATA_ROOT" ]; then
      export DFS_DATA_ROOT=/data
    fi
    # CG: This list to be reviewed
    export DHS_HOST=$OlasWS
    export DHS_CONFIG=archeso@${DHS_HOST}:/data/msg
    export DHS_DATA=${DFS_DATA_ROOT}/raw
    export DHS_LOG=${DFS_DATA_ROOT}/msg
    export BAD_DIR=${DFS_DATA_ROOT}/bad
    export DFS_DATA_RAW=${DFS_DATA_ROOT}/raw
    export DFS_DATA_REDUCED=${DFS_DATA_ROOT}/reduced
    export DFS_DATA_MSG=${DFS_DATA_ROOT}/msg
    export DFS_DATA_BACKLOG=${DFS_DATA_ROOT}/backlog
    export DFS_LOG=${DFS_DATA_ROOT}/msg
  
    #
    # Required by DataTransfer
    #
    export DFS_DT_BACKSINCE=1971-01-01
    export DFS_ADO_CONFIG=~archeso/datatransfer/config/ADOConfiguration.properties
    export DFS_NTS_CONFIG=~archeso/datatransfer/config/NTSConfiguration.properties
    export DFS_NTS4HDR_CONFIG=~archeso/datatransfer/config/NTS4hdrConfiguration.properties
    export DFS_DTS_CONFIG=~archeso/datatransfer/config/DTSConfiguration.properties
    export DFS_DTS4BACKUP_CONFIG=~archeso/datatransfer/config/DTS4backupConfiguration.properties
    export DFS_DTS4BACKUP_LOG4J=~archeso/datatransfer/config/DTS4backupLog4j.cf
    export DFS_AR_CONFIG=~archeso/datatransfer/config/ARConfiguration.properties
    export DFS_NTS4HDR_LOG4J=~archeso/datatransfer/config/NTS4hdrLog4j.cf
    export DFS_DT_POST_COMMAND="${DFS_HOME}/bin/linkToArchive %s"
    export DFS_ADO_INCOMING=${DFS_DATA_ROOT}/lists/archivedataorganizer/incoming
    export DFS_REMOVE_PAF=1
    export DFS_DATA_HDR=${DFS_DATA_ROOT}/header
    export DFS_FITS2HDR="dfits -x 0"
    export DFS_NTS_HDR_INCOMING=${DFS_DATA_ROOT}/lists/networktransferscheduler4hdr/incoming
    if [ -d /opt/python ]; then
      export PATH=/opt/python/bin:$PATH
    fi
    if [ -d ~archeso/datatransfer/bin ]; then
      export PATH=$PATH:~archeso/datatransfer/bin
    fi
    if [ -z "$PYTHONPATH" ]; then
      export PYTHONPATH=~archeso/datatransfer/lib
    else
      export PYTHONPATH=$PYTHONPATH:~archeso/datatransfer/lib
    fi
    if [ -d  ~archeso/datatransfer/config ]; then
      export PYTHONPATH=$PYTHONPATH:~archeso/datatransfer/config
    fi
    ;;
  esac
fi

unset CCS_ENVIRONMENT
unset SYBASE_SERVER
